@@ -302,8 +302,11 @@ class InfEngineServerEngine:
                 self._logger.error(f"Can't get InfEngine version: {res}")
                 raise Exception(f"Can't get InfEngine version: {res}")
             elif process_stdout.find("Release version:") != -1:
-                match = re.search("Release version: ([0-9a-zA-Z.-]+)", process_stdout)
+                full_version = re.search("Release version: ([0-9a-zA-Z.-]+)", process_stdout)
 
-                return match.group() if match else None
+                if full_version:
+                    version = full_version.group().replace("Release version: ", "")
+
+                    return version
 
         return None
